@@ -107,8 +107,8 @@ class Tatu(Storage):
     def fetchstep(self, id):
         return self.storage.fetchstep(id)
 
-    def fetchstream(self, id):
-        return self.storage.fetchstream(id)
+    def fetchstream(self, id, lazy=True):
+        return self.storage.fetchstream(id, lazy)
 
     def hasdata(self, id, include_empty=False):
         return self.storage.hasdata(id, include_empty)
